@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.22 10:00:00                  #
+# Updated Date: 2025.09.02 01:00:00                  #
 # ================================================== #
 
 import os
@@ -14,6 +14,8 @@ import builtins
 import io
 import platform
 
+import pygpt_net.icons_rc
+
 # disable warnings
 os.environ["TRANSFORMERS_NO_ADVISORY_WARNINGS"] = "1"
 os.environ["QT_LOGGING_RULES"] = "qt.multimedia.ffmpeg=false;qt.qpa.fonts=false"
@@ -87,6 +89,8 @@ from pygpt_net.plugin.slack import Plugin as SlackPlugin
 from pygpt_net.plugin.github import Plugin as GithubPlugin
 from pygpt_net.plugin.bitbucket import Plugin as BitbucketPlugin
 from pygpt_net.plugin.server import Plugin as ServerPlugin
+from pygpt_net.plugin.tuya import Plugin as TuyaPlugin
+from pygpt_net.plugin.wikipedia import Plugin as WikipediaPlugin
 
 # agents (Llama-index)
 # from pygpt_net.provider.agents.llama_index.legacy.openai import OpenAIAgent
@@ -122,6 +126,7 @@ from pygpt_net.provider.llms.ollama import OllamaLLM
 from pygpt_net.provider.llms.openai import OpenAILLM
 from pygpt_net.provider.llms.perplexity import PerplexityLLM
 from pygpt_net.provider.llms.x_ai import xAILLM
+from pygpt_net.provider.llms.open_router import OpenRouterLLM
 
 # vector store providers (llama-index)
 from pygpt_net.provider.vector_stores.chroma import ChromaProvider
@@ -166,15 +171,18 @@ from pygpt_net.provider.audio_input.openai_whisper import OpenAIWhisper
 from pygpt_net.provider.audio_input.openai_whisper_local import OpenAIWhisperLocal
 from pygpt_net.provider.audio_input.google_speech_recognition import GoogleSpeechRecognition
 from pygpt_net.provider.audio_input.google_cloud_speech_recognition import GoogleCloudSpeechRecognition
+from pygpt_net.provider.audio_input.google_genai import GoogleGenAIAudioInput
 from pygpt_net.provider.audio_input.bing_speech_recognition import BingSpeechRecognition
 from pygpt_net.provider.audio_output.openai_tts import OpenAITextToSpeech
 from pygpt_net.provider.audio_output.ms_azure_tts import MSAzureTextToSpeech
 from pygpt_net.provider.audio_output.google_tts import GoogleTextToSpeech
+from pygpt_net.provider.audio_output.google_genai_tts import GoogleGenAITextToSpeech
 from pygpt_net.provider.audio_output.eleven_labs import ElevenLabsTextToSpeech
 
 # web search engine providers
 from pygpt_net.provider.web.google_custom_search import GoogleCustomSearch
 from pygpt_net.provider.web.microsoft_bing import MicrosoftBingSearch
+from pygpt_net.provider.web.duckduck_search import DuckDuckGoSearch
 
 # tools
 from pygpt_net.tools.indexer import IndexerTool
@@ -313,10 +321,12 @@ def run(**kwargs):
     launcher.add_audio_input(OpenAIWhisperLocal())
     launcher.add_audio_input(GoogleSpeechRecognition())
     launcher.add_audio_input(GoogleCloudSpeechRecognition())
+    launcher.add_audio_input(GoogleGenAIAudioInput())
     launcher.add_audio_input(BingSpeechRecognition())
     launcher.add_audio_output(OpenAITextToSpeech())
     launcher.add_audio_output(MSAzureTextToSpeech())
     launcher.add_audio_output(GoogleTextToSpeech())
+    launcher.add_audio_output(GoogleGenAITextToSpeech())
     launcher.add_audio_output(ElevenLabsTextToSpeech())
 
     # register custom audio providers
@@ -333,6 +343,7 @@ def run(**kwargs):
     # register web providers
     launcher.add_web(GoogleCustomSearch())
     launcher.add_web(MicrosoftBingSearch())
+    launcher.add_web(DuckDuckGoSearch())
 
     # register custom web providers
     providers = kwargs.get('web', None)
@@ -407,6 +418,8 @@ def run(**kwargs):
     launcher.add_plugin(GithubPlugin())
     launcher.add_plugin(BitbucketPlugin())
     launcher.add_plugin(ServerPlugin())
+    launcher.add_plugin(TuyaPlugin())
+    launcher.add_plugin(WikipediaPlugin())
 
     # register custom plugins
     plugins = kwargs.get('plugins', None)
@@ -428,6 +441,7 @@ def run(**kwargs):
     launcher.add_llm(DeepseekApiLLM())
     launcher.add_llm(PerplexityLLM())
     launcher.add_llm(xAILLM())
+    launcher.add_llm(OpenRouterLLM())
 
     # register LLMs
     llms = kwargs.get('llms', None)
