@@ -1,4 +1,4 @@
-# !/usr/bin/env python3
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 # ================================================== #
 # This file is a part of PYGPT package               #
@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.20 23:00:00                  #
+# Updated Date: 2025.09.01 23:00:00                  #
 # ================================================== #
 
 from pygpt_net.controller.access import Access
@@ -29,17 +29,19 @@ from pygpt_net.controller.kernel import Kernel
 from pygpt_net.controller.lang import Lang
 from pygpt_net.controller.launcher import Launcher
 from pygpt_net.controller.layout import Layout
+from pygpt_net.controller.media import Media
 from pygpt_net.controller.mode import Mode
 from pygpt_net.controller.model import Model
 from pygpt_net.controller.notepad import Notepad
 from pygpt_net.controller.painter import Painter
 from pygpt_net.controller.plugins import Plugins
+from pygpt_net.controller.realtime import Realtime
 from pygpt_net.controller.presets import Presets
 from pygpt_net.controller.settings import Settings
 from pygpt_net.controller.theme import Theme
 from pygpt_net.controller.tools import Tools
 from pygpt_net.controller.ui import UI
-from pygpt_net.utils import mem_clean
+from pygpt_net.utils import trans
 
 
 class Controller:
@@ -70,12 +72,14 @@ class Controller:
         self.lang = Lang(window)
         self.launcher = Launcher(window)
         self.layout = Layout(window)
+        self.media = Media(window)
         self.mode = Mode(window)
         self.model = Model(window)
         self.notepad = Notepad(window)
         self.painter = Painter(window)
         self.plugins = Plugins(window)
         self.presets = Presets(window)
+        self.realtime = Realtime(window)
         self.settings = Settings(window)
         self.theme = Theme(window)
         self.tools = Tools(window)
@@ -108,8 +112,8 @@ class Controller:
         self.attachment.setup()
         self.camera.setup_ui()
         self.access.setup()
-
-
+        self.realtime.setup()
+        self.media.setup()
 
     def post_setup(self):
         """Post-setup, after plugins are loaded"""
@@ -147,9 +151,7 @@ class Controller:
         """Reload components"""
         self.reloading = True  # lock
 
-        print("Reloading components... please wait...")
-
-        mem_clean()  # try to clean memory
+        print(trans("status.reloading.profile.begin"))
 
         prev_theme = self.window.core.config.get("theme")
 
@@ -170,6 +172,7 @@ class Controller:
         self.lang.reload()
         self.debug.reload()
         self.chat.reload()
+        self.media.reload()
         self.window.tools.on_reload()
         self.access.reload()
         self.tools.reload()
@@ -183,4 +186,4 @@ class Controller:
 
         self.reloading = False  # unlock
 
-        print("[OK] Components reloaded successfully.")
+        print(trans("status.reloading.profile.end"))
