@@ -6,13 +6,13 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.03 14:00:00                  #
+# Updated Date: 2025.09.02 22:00:00                  #
 # ================================================== #
 
 from typing import Optional, Any
 
-from qasync import QApplication
-from PySide6.QtWidgets import QFileDialog
+from PySide6.QtCore import QTimer
+from PySide6.QtWidgets import QFileDialog, QApplication
 
 from pygpt_net.utils import trans
 
@@ -43,7 +43,7 @@ class Batch:
 
         # run asynchronous
         self.window.update_status("Importing assistants...please wait...")
-        self.window.core.gpt.assistants.importer.import_assistants()
+        self.window.core.api.openai.assistants.importer.import_assistants()
 
     def import_stores(self, force: bool = False):
         """
@@ -61,7 +61,7 @@ class Batch:
         # run asynchronous
         self.window.update_status("Importing vector stores...please wait...")
         self.window.core.assistants.store.truncate()  # clear all stores
-        self.window.core.gpt.assistants.importer.import_vector_stores()
+        self.window.core.api.openai.assistants.importer.import_vector_stores()
         self.window.controller.assistant.files.update()
         self.window.controller.assistant.store.update()
 
@@ -141,7 +141,7 @@ class Batch:
         # run asynchronous
         self.window.update_status("Removing files...please wait...")
         QApplication.processEvents()
-        self.window.core.gpt.assistants.importer.truncate_files()  # remove all files from API
+        self.window.core.api.openai.assistants.importer.truncate_files()  # remove all files from API
 
     def truncate_store_files_by_idx(self, idx: int, force: bool = False):
         """
@@ -174,7 +174,7 @@ class Batch:
         # run asynchronous
         self.window.update_status("Removing files...please wait...")
         QApplication.processEvents()
-        self.window.core.gpt.assistants.importer.truncate_files(store_id)  # remove all files from API
+        self.window.core.api.openai.assistants.importer.truncate_files(store_id)  # remove all files from API
 
     def clear_store_files_by_idx(
             self,
@@ -278,7 +278,7 @@ class Batch:
         self.window.update_status("Removing vector stores...please wait...")
         QApplication.processEvents()
         self.window.core.assistants.store.truncate()  # clear all stores
-        self.window.core.gpt.assistants.importer.truncate_vector_stores()
+        self.window.core.api.openai.assistants.importer.truncate_vector_stores()
         self.window.controller.assistant.files.update()
         self.window.controller.assistant.store.update()
         self.window.controller.assistant.store.current = None
@@ -299,7 +299,7 @@ class Batch:
             return
         self.window.update_status("Refreshing vector stores...please wait...")
         QApplication.processEvents()
-        self.window.core.gpt.assistants.importer.refresh_vector_stores()
+        self.window.core.api.openai.assistants.importer.refresh_vector_stores()
 
     def handle_imported_assistants(self, num: int):
         """
@@ -527,6 +527,15 @@ class Batch:
                 msg=msg,
             )
 
+    def refresh_delayed(self, ms: int = 1000):
+        """
+        Refresh UI after delay
+
+        :param ms: milliseconds to wait
+        """
+        self.window.update_status("Refreshing status...")
+        QTimer.singleShot(ms, lambda: self.window.controller.assistant.store.refresh_status())
+
     def upload(self, force: bool = False):
         """
         Upload files to vector store
@@ -540,7 +549,7 @@ class Batch:
         store_id = self.window.controller.assistant.store.current
         self.window.update_status("Uploading files...please wait...")
         QApplication.processEvents()
-        self.window.core.gpt.assistants.importer.upload_files(store_id, self.files_to_upload)
+        self.window.core.api.openai.assistants.importer.upload_files(store_id, self.files_to_upload)
         self.files_to_upload = []  # clear files
 
     def handle_uploaded_files(self, num: int):
@@ -549,10 +558,10 @@ class Batch:
 
         :param num: number of uploaded files
         """
-        self.window.controller.assistant.files.update()
-        self.window.controller.assistant.store.refresh_status()
+        self.window.controller.assistant.files.update()        
         self.window.update_status("OK. Uploaded files: " + str(num) + ".")
         self.window.ui.dialogs.alert("OK. Uploaded files: " + str(num) + ".")
+        self.refresh_delayed(1500)
 
     def handle_uploaded_files_failed(self, error: Any):
         """
@@ -563,7 +572,7 @@ class Batch:
         self.window.core.debug.log(error)
         print("Error uploading files")
         self.window.controller.assistant.files.update()
-        self.window.controller.assistant.store.refresh_status()
+        self.refresh_delayed(1500)
         self.window.update_status("Error uploading files.")
         self.window.ui.dialogs.alert(error)
 
