@@ -55,8 +55,8 @@ class Custom:
         self.window.ui.config['preset'][MODE_CHAT].box.setText(trans("preset.chat"))
         self.window.ui.config['preset'][MODE_COMPLETION].box.setText(trans("preset.completion"))
         self.window.ui.config['preset'][MODE_IMAGE].box.setText(trans("preset.img"))
-        self.window.ui.config['preset'][MODE_VISION].box.setText(trans("preset.vision"))
-        #self.window.ui.config['preset'][MODE_LANGCHAIN].box.setText(trans("preset.langchain"))
+        # self.window.ui.config['preset'][MODE_VISION].box.setText(trans("preset.vision"))
+        # self.window.ui.config['preset'][MODE_LANGCHAIN].box.setText(trans("preset.langchain"))
         self.window.ui.config['preset'][MODE_LLAMA_INDEX].box.setText(trans("preset.llama_index"))
         self.window.ui.config['preset'][MODE_AGENT].box.setText(trans("preset.agent"))
         self.window.ui.config['preset'][MODE_AGENT_LLAMA].box.setText(trans("preset.agent_llama"))
