@@ -6,14 +6,14 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.02 20:00:00                  #
+# Updated Date: 2025.08.26 23:00:00                  #
 # ================================================== #
 
 import copy
 import os
 from typing import List, Dict, Optional, Any
 
-from qasync import QApplication
+from PySide6.QtWidgets import QApplication
 
 from pygpt_net.core.events import Event
 from pygpt_net.core.types import (
@@ -391,7 +391,7 @@ class Importer:
                         'type': 'str'
                     }
                 ]
-            elif self.provider == "openai":
+            elif self.provider in ["openai", "azure_openai"]:
                 m.tool_calls = True
                 m.llama_index['env'] = [
                     {
@@ -429,12 +429,49 @@ class Importer:
                         'type': 'str'
                     }
                 ]
+            elif self.provider == "mistral_ai":
+                m.tool_calls = True
+                m.llama_index['args'].append(
+                    {
+                        'name': 'api_key',
+                        'value': '{api_key_mistral}',
+                        'type': 'str'
+                    }
+                )
+            elif self.provider == "local_ai":
+                m.tool_calls = True
+                m.llama_index['env'] = [
+                    {
+                        'name': 'OPENAI_API_KEY',
+                        'value': '{api_key}',
+                        'type': 'str'
+                    },
+                    {
+                        'name': 'OPENAI_API_BASE',
+                        'value': '{api_endpoint}',
+                        'type': 'str'
+                    }
+                ]
+            elif self.provider == "open_router":
+                m.tool_calls = True
+                m.llama_index['env'] = [
+                    {
+                        'name': 'OPENAI_API_KEY',
+                        'value': '{api_key_open_router}',
+                        'type': 'str'
+                    },
+                    {
+                        'name': 'OPENAI_API_BASE',
+                        'value': '{api_endpoint_open_router}',
+                        'type': 'str'
+                    }
+                ]
             elif self.provider == "x_ai":
                 m.tool_calls = True
                 m.llama_index['env'] = [
                     {
                         'name': 'OPENAI_API_KEY',
-                        'value': '{api_key_xai',
+                        'value': '{api_key_xai}',
                         'type': 'str'
                     },
                     {
@@ -475,6 +512,7 @@ class Importer:
                         MODE_LLAMA_INDEX,
                         MODE_AGENT,
                         MODE_AGENT_LLAMA,
+                        MODE_AGENT_OPENAI,
                         MODE_EXPERT,
                     ]
                     m.provider = 'ollama'
@@ -586,9 +624,9 @@ class Importer:
         :return: Dict with keys and values
         """
         excluded = [
-            "azure_openai",
+            #"azure_openai",
             "huggingface_api",
-            "mistral_ai",
+            #"mistral_ai",
             "local_ai",
             "perplexity",
         ]
