@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.11 14:00:00                  #
+# Updated Date: 2025.09.04 00:00:00                  #
 # ================================================== #
 
 from PySide6.QtCore import QObject, Signal, QRunnable, Slot
@@ -17,6 +17,8 @@ from pygpt_net.core.types import (
     MODE_LANGCHAIN,
     MODE_LLAMA_INDEX,
     MODE_ASSISTANT,
+    MODE_VISION,
+    MODE_LOOP_NEXT,
 )
 from pygpt_net.core.events import KernelEvent, Event
 
@@ -27,10 +29,13 @@ class BridgeSignals(QObject):
 
 
 class BridgeWorker(QRunnable):
+    __slots__ = ('signals', 'rt_signals', 'args', 'kwargs', 'window', 'context', 'extra', 'mode')
+
     """Bridge worker"""
     def __init__(self, *args, **kwargs):
-        QRunnable.__init__(self)
+        super().__init__()
         self.signals = BridgeSignals()
+        self.rt_signals = None
         self.args = args
         self.kwargs = kwargs
         self.window = None
@@ -64,6 +69,8 @@ class BridgeWorker(QRunnable):
                     extra=self.extra,
                 )
                 """
+            elif self.mode == MODE_VISION:
+                raise Exception("Vision mode is deprecated from v2.6.30 and integrated into Chat. ")
 
             # LlamaIndex: chat with files
             if self.mode == MODE_LLAMA_INDEX:
@@ -87,7 +94,7 @@ class BridgeWorker(QRunnable):
                     self.extra["error"] = str(self.window.core.agents.runner.get_error())
 
             # Loop: next step
-            elif self.mode == "loop_next":  # virtual mode
+            elif self.mode == MODE_LOOP_NEXT:  # virtual mode
                 result = self.window.core.agents.runner.loop.run_next(
                     context=self.context,
                     extra=self.extra,
@@ -98,12 +105,29 @@ class BridgeWorker(QRunnable):
                 else:
                     self.extra["error"] = str(self.window.core.agents.runner.get_error())
 
-            # API OpenAI: chat, completion, vision, image, assistants
+            # API SDK: chat, completion, vision, image, assistants
             else:
-                result = self.window.core.gpt.call(
-                    context=self.context,
-                    extra=self.extra,
-                )
+                sdk = "openai"
+                model = self.context.model
+                if model.provider == "google":
+                    if self.window.core.config.get("api_native_google", False):
+                        sdk = "google"
+
+                # call appropriate SDK
+                if sdk == "google":
+                    # print("Using Google SDK")
+                    result = self.window.core.api.google.call(
+                        context=self.context,
+                        extra=self.extra,
+                        rt_signals=self.rt_signals,
+                    )
+                elif sdk == "openai":
+                    # print("Using OpenAI SDK")
+                    result = self.window.core.api.openai.call(
+                        context=self.context,
+                        extra=self.extra,
+                        rt_signals=self.rt_signals,
+                    )
         except Exception as e:
             if self.signals:
                 self.extra["error"] = e
@@ -170,7 +194,7 @@ class BridgeWorker(QRunnable):
         ad_context = self.window.controller.chat.attachment.get_context(ctx, self.context.history)
         ad_mode = self.window.controller.chat.attachment.get_mode()
         if ad_context:
-            self.context.prompt += "\n\n" + ad_context  # append to input text
+            self.context.prompt += f"\n\n{ad_context}"  # append to input text
             if (ad_mode == self.window.controller.chat.attachment.MODE_QUERY_CONTEXT
                     or self.mode in [MODE_AGENT_LLAMA, MODE_AGENT_OPENAI]):
                 ctx.hidden_input = ad_context  # store for future use, only if query context
