@@ -6,9 +6,9 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.11 00:00:00                  #
+# Updated Date: 2025.08.24 02:00:00                  #
 # ================================================== #
-
+import json
 import re
 import html
 
@@ -136,7 +136,7 @@ class Helpers:
         :return: formatted text
         """
         s = text
-        if self.window.core.config.get("llama.idx.chat.agent.render.all", False):
+        if self.window.core.config.get("agent.output.render.all", False):
             if "__agent_begin__" in s or "__agent_end__" in s:
                 s = s.replace("__agent_begin__", '<div class="msg-agent">').replace("__agent_end__", "</div>")
         return s.strip()
@@ -155,14 +155,24 @@ class Helpers:
             s = f'<div class="cmd">&gt; {s}</div>'
         return s
 
-    def format_cmd_text(self, text: str) -> str:
+    def format_cmd_text(self, text: str, indent: bool = False) -> str:
         """
         Post-format cmd text
 
         :param text: text to format
+        :param indent: whether to indent text
         :return: formatted text
         """
-        return html.escape(text)
+        if not text:
+            return ""
+        if not indent:
+            return html.escape(text)
+        else:
+            try:
+                return html.escape(json.dumps(json.loads(text), indent=2))
+            except Exception:
+                return html.escape(text)
+
 
     def format_chunk(self, text: str) -> str:
         """
