@@ -6,16 +6,19 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.19 07:00:00                  #
+# Updated Date: 2025.09.04 00:00:00                  #
 # ================================================== #
 
 import json
 import os
 import re
+import gc
+from dataclasses import dataclass, field
 
 from datetime import datetime
 from typing import Optional, List, Any
 from time import monotonic
+from io import StringIO
 
 from pygpt_net.core.render.base import BaseRenderer
 from pygpt_net.core.text.utils import has_unclosed_code_tag
@@ -48,6 +51,46 @@ class Renderer(BaseRenderer):
     )
     RE_AMP_LT_GT = re.compile(r'&amp;(lt|gt);')
 
+    @dataclass(slots=True)
+    class _AppendBuffer:
+        """Small, allocation-friendly buffer for throttled appends."""
+        _buf: StringIO = field(default_factory=StringIO, repr=False)
+        _size: int = 0
+
+        def append(self, s: str) -> None:
+            if not s:
+                return
+            self._buf.write(s)
+            self._size += len(s)
+
+        def is_empty(self) -> bool:
+            return self._size == 0
+
+        def get_and_clear(self) -> str:
+            """Return content and replace underlying buffer to release memory eagerly."""
+            if self._size == 0:
+                return ""
+            data = self._buf.getvalue()
+            old = self._buf
+            # Replace the internal buffer instance to drop capacity immediately
+            self._buf = StringIO()
+            self._size = 0
+            try:
+                old.close()
+            except Exception:
+                pass
+            return data
+
+        def clear(self) -> None:
+            """Clear content and drop buffer capacity."""
+            old = self._buf
+            self._buf = StringIO()
+            self._size = 0
+            try:
+                old.close()
+            except Exception:
+                pass
+
     def __init__(self, window=None):
         super(Renderer, self).__init__(window)
         """
@@ -69,7 +112,7 @@ class Renderer(BaseRenderer):
         self._file_prefix = 'file:///' if self.window and self.window.core.platforms.is_windows() else 'file://'
 
         self._thr = {}
-        self._throttle_interval = 0.01 # 10 ms delay
+        self._throttle_interval = 0.03  # 30 ms delay
 
     def prepare(self):
         """
@@ -328,6 +371,9 @@ class Renderer(BaseRenderer):
         except Exception:
             pass
 
+        # release strings
+        gc.collect()
+
     def append_context(
             self,
             meta: CtxMeta,
@@ -594,10 +640,10 @@ class Renderer(BaseRenderer):
         """
         output = ctx.output
         if isinstance(ctx.extra, dict) and ctx.extra.get("output"):
-            if self.window.core.config.get("llama.idx.chat.agent.render.all", False):
-                output = f"__agent_begin__{ctx.output}__agent_end__{ctx.extra['output']}"
+            if self.window.core.config.get("agent.output.render.all", False):
+                output = ctx.output  # full agent output
             else:
-                output = ctx.extra["output"]
+                output = ctx.extra["output"]  # final output only
         else:
             if not output:
                 return
@@ -656,6 +702,7 @@ class Renderer(BaseRenderer):
         pid = self.get_or_create_pid(meta)
         pctx = self.pids[pid]
         pctx.item = ctx
+
         if not text_chunk:
             if begin:
                 pctx.clear()
@@ -663,13 +710,16 @@ class Renderer(BaseRenderer):
                 self._throttle_reset(pid)
             return
 
-        if begin:  # prepare name and avatar header only at the beginning to avoid unnecessary checks
+        if begin:
+            # Prepare name header once per streaming session
             pctx.header = self.get_name_header(ctx, stream=True)
             self.update_names(meta, ctx)
 
         name_header_str = pctx.header
         text_chunk = text_chunk if isinstance(text_chunk, str) else str(text_chunk)
-        text_chunk = text_chunk.translate({ord('<'): '&lt;', ord('>'): '&gt;'})
+        # Escape angle brackets only if present to avoid unnecessary allocations
+        if ('<' in text_chunk) or ('>' in text_chunk):
+            text_chunk = text_chunk.translate({ord('<'): '&lt;', ord('>'): '&gt;'})
 
         if begin:
             if self.is_debug():
@@ -683,42 +733,69 @@ class Renderer(BaseRenderer):
             self.clear_chunks_output(pid)
             self.prev_chunk_replace = False
 
+        # Append to the logical buffer (owned by pid)
         pctx.append_buffer(text_chunk)
-
         buffer = pctx.buffer
-        if has_unclosed_code_tag(buffer):
-            buffer_to_parse = "".join((buffer, "\n```"))
-        else:
-            buffer_to_parse = buffer
 
-        html = self.parser.parse(buffer_to_parse)
-        del buffer_to_parse
-        is_code_block = html.endswith(self.ENDINGS_CODE)
-        is_list = html.endswith(self.ENDINGS_LIST)
+        # Cheap detection of open code fence without full parse
+        open_code = has_unclosed_code_tag(buffer)
+
+        # Newline/flow state
         is_n = "\n" in text_chunk
-        is_newline = is_n or buffer.endswith("\n") or is_code_block
-        force_replace = False
-        if self.prev_chunk_newline:
-            force_replace = True
-        if is_n:
-            self.prev_chunk_newline = True
-        else:
-            self.prev_chunk_newline = False
+        is_newline = is_n or buffer.endswith("\n") or open_code
+        force_replace = self.prev_chunk_newline
+        self.prev_chunk_newline = bool(is_n)
 
         replace = False
-        if is_newline or force_replace or is_list:
+        if is_newline or force_replace:
             replace = True
-            if is_code_block:
-                if not is_n:
-                    replace = False
+            # Do not replace for an open code block unless a newline arrived
+            if open_code and not is_n:
+                replace = False
 
+        thr = self._throttle_get(pid)
+        html = None
+
+        # Only parse when required:
+        # - a replace is needed now, or
+        # - a replace is pending in the throttle and must be refreshed, or
+        # - rarely: we must detect list termination without a newline
+        need_parse_for_pending_replace = (thr["op"] == 1)
+        need_parse_for_list = False
+
+        if not replace:
+            # Very rare case: list closing without newline. Check on a short tail only.
+            # This keeps behavior intact while avoiding full-buffer parse on every chunk.
+            tail = buffer[-4096:]
+            if tail:
+                tail_to_parse = f"{tail}\n```" if open_code else tail
+                tail_html = self.parser.parse(tail_to_parse)
+                need_parse_for_list = tail_html.endswith(self.ENDINGS_LIST)
+                # Tail string is short and will be collected promptly
+                del tail_html
+            if need_parse_for_list:
+                replace = True
+
+        if replace or need_parse_for_pending_replace:
+            buffer_to_parse = f"{buffer}\n```" if open_code else buffer
+            html = self.parser.parse(buffer_to_parse)
+            # Help the GC by breaking the reference as soon as possible
+            del buffer_to_parse
+
+        is_code_block = open_code
+
+        # Adjust output chunk formatting based on block type
         if not is_code_block:
             if is_n:
+                # Convert text newlines to <br/> in non-code context
                 text_chunk = text_chunk.replace("\n", "<br/>")
         else:
+            # When previous operation replaced content and this chunk closes the fence,
+            # prepend a newline so the final code block renders correctly.
             if self.prev_chunk_replace and (is_code_block and not has_unclosed_code_tag(text_chunk)):
                 text_chunk = "\n" + text_chunk
 
+        # Update replace flag for next iteration AFTER formatting decisions
         self.prev_chunk_replace = replace
 
         if begin:
@@ -727,7 +804,19 @@ class Renderer(BaseRenderer):
             except Exception:
                 pass
 
-        self._throttle_queue(pid, name_header_str or "", html, text_chunk, replace, is_code_block)
+        # Queue throttled emission; HTML is only provided when it is really needed
+        self._throttle_queue(
+            pid=pid,
+            name=name_header_str or "",
+            html=html if html is not None else "",
+            text_chunk=text_chunk,
+            replace=replace,
+            is_code_block=is_code_block,
+        )
+        # Explicitly drop local ref to large html string as early as possible
+        html = None
+
+        # Emit if throttle interval allows
         self._throttle_emit(pid, force=False)
 
     def next_chunk(
@@ -1276,7 +1365,7 @@ class Renderer(BaseRenderer):
             extra = ctx.extra["footer"]
             extra_style = "display:block;"
 
-        return  f'<div class="msg-box msg-user" id="{msg_id}"><div class="name-header name-user">{name}</div><div class="msg">{html}<div class="msg-extra" style="{extra_style}">{extra}</div>{debug}</div></div>'
+        return f'<div class="msg-box msg-user" id="{msg_id}"><div class="name-header name-user">{name}</div><div class="msg">{html}<div class="msg-extra" style="{extra_style}">{extra}</div>{debug}</div></div>'
 
     def prepare_node_output(
             self,
@@ -1289,7 +1378,7 @@ class Renderer(BaseRenderer):
         """
         Prepare output node
 
-        :param meta: context meta
+        :param meta: CtxMeta
         :param ctx: CtxItem instance
         :param html: html text
         :param prev_ctx: previous context item
@@ -1317,15 +1406,15 @@ class Renderer(BaseRenderer):
         if is_cmd:
             if ctx.results is not None and len(ctx.results) > 0 \
                     and isinstance(ctx.extra, dict) and "agent_step" in ctx.extra:
-                tool_output = self.helpers.format_cmd_text(str(ctx.input))
+                tool_output = self.helpers.format_cmd_text(str(ctx.input), indent=True)
                 output_class = ""
             else:
-                tool_output = self.helpers.format_cmd_text(str(next_ctx.input))
+                tool_output = self.helpers.format_cmd_text(str(next_ctx.input), indent=True)
                 output_class = ""
 
         elif ctx.results is not None and len(ctx.results) > 0 \
                 and isinstance(ctx.extra, dict) and "agent_step" in ctx.extra:
-            tool_output = self.helpers.format_cmd_text(str(ctx.input))
+            tool_output = self.helpers.format_cmd_text(str(ctx.input), indent=True)
         else:
             out = (getattr(ctx, "output", "") or "")
             cmds = getattr(ctx, "cmds", ())
@@ -1772,6 +1861,9 @@ class Renderer(BaseRenderer):
         """
         if not html:
             return ""
+        # Fast path: avoid regex work and extra allocations when not needed
+        if '&amp;' not in html:
+            return html
         return self.RE_AMP_LT_GT.sub(r'&\1;', html)
 
     def append_debug(
@@ -1819,7 +1911,14 @@ class Renderer(BaseRenderer):
         """
         thr = self._thr.get(pid)
         if thr is None:
-            thr = {"last": 0.0, "op": 0, "name": "", "replace_html": "", "append": [], "code": False}
+            thr = {
+                "last": 0.0,
+                "op": 0,
+                "name": "",
+                "replace_html": "",
+                "append": Renderer._AppendBuffer(),
+                "code": False,
+            }
             self._thr[pid] = thr
         return thr
 
@@ -1837,7 +1936,8 @@ class Renderer(BaseRenderer):
         thr["op"] = 0
         thr["name"] = ""
         thr["replace_html"] = ""
-        thr["append"].clear()
+        # Replace append buffer instance to drop any capacity eagerly
+        thr["append"] = Renderer._AppendBuffer()
         thr["code"] = False
 
     def _throttle_queue(
@@ -1866,10 +1966,12 @@ class Renderer(BaseRenderer):
         if replace:
             thr["op"] = 1
             thr["replace_html"] = html
+            # Drop previous append items aggressively when a replace snapshot is available
             thr["append"].clear()
             thr["code"] = bool(is_code_block)
         else:
             if thr["op"] == 1:
+                # Refresh the pending replace with the latest HTML snapshot
                 thr["replace_html"] = html
                 thr["code"] = bool(is_code_block)
                 return
@@ -1895,17 +1997,21 @@ class Renderer(BaseRenderer):
 
         try:
             if thr["op"] == 1:
+                # Replace snapshot
+                replace_payload = self.sanitize_html(thr["replace_html"])
                 node.page().bridge.chunk.emit(
                     thr["name"],
-                    self.sanitize_html(thr["replace_html"]),
+                    replace_payload,
                     "",
                     True,
                     bool(thr["code"]),
                 )
+                thr["replace_html"] = ""  # Cut reference ASAP
                 thr["last"] = now
 
-                if thr["append"]:
-                    append_str = "".join(thr["append"])
+                # Append tail (if any)
+                if not thr["append"].is_empty():
+                    append_str = thr["append"].get_and_clear()
                     node.page().bridge.chunk.emit(
                         thr["name"],
                         "",
@@ -1917,8 +2023,8 @@ class Renderer(BaseRenderer):
 
                 self._throttle_reset(pid)
 
-            elif thr["op"] == 2 and thr["append"]:
-                append_str = "".join(thr["append"])
+            elif thr["op"] == 2 and not thr["append"].is_empty():
+                append_str = thr["append"].get_and_clear()
                 node.page().bridge.chunk.emit(
                     thr["name"],
                     "",
