@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.12 19:00:00                  #
+# Updated Date: 2025.08.26 01:00:00                  #
 # ================================================== #
 
 import copy
@@ -16,8 +16,6 @@ from typing import Dict, Any, Tuple, Literal, Optional
 from agents import (
     Agent as OpenAIAgent,
     Runner,
-    RunConfig,
-    ModelSettings,
     TResponseInputItem,
 )
 
@@ -32,12 +30,12 @@ from pygpt_net.item.ctx import CtxItem
 from pygpt_net.item.model import ModelItem
 from pygpt_net.item.preset import PresetItem
 
-from pygpt_net.provider.gpt.agents.client import get_custom_model_provider, set_openai_env
-from pygpt_net.provider.gpt.agents.remote_tools import get_remote_tools, is_computer_tool, append_tools
-from pygpt_net.provider.gpt.agents.response import StreamHandler
+from pygpt_net.provider.api.openai.agents.remote_tools import append_tools
+from pygpt_net.provider.api.openai.agents.response import StreamHandler
+from pygpt_net.provider.api.openai.agents.experts import get_experts
+from pygpt_net.utils import trans
 
 from ..base import BaseAgent
-from ...gpt.agents.experts import get_experts
 
 
 @dataclass
@@ -94,7 +92,7 @@ class Agent(BaseAgent):
         kwargs = {
             "name": agent_name,
             "instructions": self.get_option(preset, "base", "prompt"),
-            "model": model.id,
+            "model": window.core.agents.provider.get_openai_model(model),
         }
         if handoffs:
             kwargs["handoffs"] = handoffs
@@ -135,7 +133,7 @@ class Agent(BaseAgent):
         kwargs = {
             "name": "evaluator",
             "instructions": instructions,
-            "model": model.id,
+            "model": window.core.agents.provider.get_openai_model(model),
             "output_type": EvaluationFeedback,
         }
         tool_kwargs = append_tools(
@@ -174,7 +172,7 @@ class Agent(BaseAgent):
         kwargs = {
             "name": "chooser",
             "instructions": instructions,
-            "model": model.id,
+            "model": window.core.agents.provider.get_openai_model(model),
             "output_type": ChooseFeedback,
         }
         tool_kwargs = append_tools(
@@ -267,11 +265,7 @@ class Agent(BaseAgent):
         kwargs = {
             "max_turns": int(max_steps),
         }
-        if model.provider != "openai":
-            custom_provider = get_custom_model_provider(window, model)
-            kwargs["run_config"] = RunConfig(model_provider=custom_provider)
-        else:
-            set_openai_env(window)
+        if model.provider == "openai":
             if previous_response_id:
                 kwargs["previous_response_id"] = previous_response_id
 
@@ -346,7 +340,7 @@ class Agent(BaseAgent):
 
                 print("Winner: agent ", choose)
 
-                final_output, last_response_id = window.core.gpt.responses.unpack_agent_response(results[choose], ctx)
+                final_output, last_response_id = window.core.api.openai.responses.unpack_agent_response(results[choose], ctx)
                 input_items = results[choose].to_input_list()
 
                 if bridge.stopped():
@@ -383,7 +377,7 @@ class Agent(BaseAgent):
                     )
 
                 if num_generation >= max_generations > 0:
-                    info = f"\n\n**Max generations reached ({max_generations}), exiting.**\n"
+                    info = f"\n\n**{trans('agent.evolve.maxgen_limit')}**\n"
                     ctx.stream = info
                     bridge.on_step(ctx, False)
                     final_output += info
@@ -394,7 +388,7 @@ class Agent(BaseAgent):
             handler = StreamHandler(window, bridge)
             begin = True
             while True:
-                ctx.stream = f"\n\n\n\n**Generation {num_generation}**\n\n"
+                ctx.stream = f"\n\n\n\n**{trans('agent.evolve.generation')} {num_generation}**\n\n"
                 bridge.on_step(ctx, begin)
                 handler.begin = False
                 begin = False
@@ -407,7 +401,7 @@ class Agent(BaseAgent):
                         parents[j],
                         **parent_kwargs
                     )
-                    ctx.stream = f"\n\n**Running agent {j} ...**\n\n"
+                    ctx.stream = f"\n\n**{trans('agent.evolve.running')} {j} ...**\n\n"
                     bridge.on_step(ctx)
                     handler.reset()
                     async for event in results[j].stream_events():
@@ -436,22 +430,22 @@ class Agent(BaseAgent):
 
                 handler.to_buffer(results[choose].final_output)
                 final_output = handler.buffer
-                ctx.stream = f"**Winner: agent {result.answer_number}**\n\n"
+                ctx.stream = f"**{trans('agent.evolve.winner')} {result.answer_number}**\n\n"
                 bridge.on_step(ctx)
 
                 if bridge.stopped():
                     bridge.on_stop(ctx)
                     break
 
-                window.core.gpt.responses.unpack_agent_response(results[choose], ctx)
+                window.core.api.openai.responses.unpack_agent_response(results[choose], ctx)
                 input_items = results[choose].to_input_list()
 
                 evaluator_result = await Runner.run(evaluator, input_items)
                 result: EvaluationFeedback = evaluator_result.final_output
 
-                info = f"\n___\n**Evaluator score: {result.score}**\n\n"
+                info = f"\n___\n**{trans('agent.eval.score')}: {result.score}**\n\n"
                 if result.score == "pass":
-                    info += "\n\n**Response is good enough, exiting.**\n"
+                    info += f"\n\n**{trans('agent.eval.score.good')}.**\n"
                     if use_partial_ctx:
                         ctx = bridge.on_next_ctx(
                             ctx=ctx,
@@ -467,9 +461,9 @@ class Agent(BaseAgent):
                         final_output += info
                     break
                 else:
-                    info = f"\n___\n**Evaluator score: {result.score}**\n\n"
+                    info = f"\n___\n**{trans('agent.eval.score')}: {result.score}**\n\n"
 
-                info += "\n\n**Re-running with feedback**\n\n" + f"Feedback: {result.feedback}\n___\n"
+                info += f"\n\n**{trans('agent.eval.next')}**\n\nFeedback: {result.feedback}\n___\n"
                 input_items.append({"content": f"Feedback: {result.feedback}", "role": "user"})
 
                 if use_partial_ctx:
@@ -487,7 +481,7 @@ class Agent(BaseAgent):
                     handler.to_buffer(info)
 
                 if num_generation >= max_generations > 0:
-                    info = f"\n\n**Max generations reached ({max_generations}), exiting.**\n"
+                    info = f"\n\n**{trans('agent.evolve.maxgen_limit')}**\n"
                     ctx.stream = info
                     bridge.on_step(ctx, False)
                     final_output += info
@@ -506,94 +500,94 @@ class Agent(BaseAgent):
         """
         return {
             "base": {
-                "label": "Base agent",
+                "label": trans("agent.option.section.base"),
                 "options": {
                     "num_parents": {
                         "type": "int",
-                        "label": "Num of parents",
+                        "label": trans("agent.evolve.option.num_parents"),
                         "min": 1,
                         "default": 2,
                     },
                     "max_generations": {
                         "type": "int",
-                        "label": "Max generations",
+                        "label": trans("agent.evolve.option.max_generations"),
                         "min": 1,
                         "default": 10,
                     },
                     "prompt": {
                         "type": "textarea",
-                        "label": "Prompt",
-                        "description": "Prompt for base agent",
+                        "label": trans("agent.option.prompt"),
+                        "description": trans("agent.option.prompt.desc"),
                         "default": self.PROMPT,
                     },
                     "allow_local_tools": {
                         "type": "bool",
-                        "label": "Allow local tools",
-                        "description": "Allow usage of local tools for this agent",
+                        "label": trans("agent.option.tools.local"),
+                        "description": trans("agent.option.tools.local.desc"),
                         "default": False,
                     },
                     "allow_remote_tools": {
                         "type": "bool",
-                        "label": "Allow remote tools",
-                        "description": "Allow usage of remote tools for this agent",
+                        "label": trans("agent.option.tools.remote"),
+                        "description": trans("agent.option.tools.remote.desc"),
                         "default": False,
                     },
                 }
             },
             "chooser": {
-                "label": "Chooser",
+                "label": trans("agent.option.section.chooser"),
                 "options": {
                     "model": {
-                        "label": "Model",
+                        "label": trans("agent.option.model"),
                         "type": "combo",
                         "use": "models",
                         "default": "gpt-4o",
                     },
                     "prompt": {
                         "type": "textarea",
-                        "label": "Prompt",
-                        "description": "Prompt for chooser agent",
+                        "label": trans("agent.option.prompt"),
+                        "description": trans("agent.option.prompt.chooser.desc"),
                         "default": self.PROMPT_CHOOSE,
                     },
                     "allow_local_tools": {
                         "type": "bool",
-                        "label": "Allow local tools",
-                        "description": "Allow usage of local tools for this agent",
+                        "label": trans("agent.option.tools.local"),
+                        "description": trans("agent.option.tools.local.desc"),
                         "default": False,
                     },
                     "allow_remote_tools": {
                         "type": "bool",
-                        "label": "Allow remote tools",
-                        "description": "Allow usage of remote tools for this agent",
+                        "label": trans("agent.option.tools.remote"),
+                        "description": trans("agent.option.tools.remote.desc"),
                         "default": False,
                     },
                 }
             },
             "feedback": {
-                "label": "Feedback",
+                "label": trans("agent.option.section.feedback"),
                 "options": {
                     "model": {
-                        "label": "Model",
+                        "label": trans("agent.option.model"),
                         "type": "combo",
                         "use": "models",
                         "default": "gpt-4o",
                     },
                     "prompt": {
                         "type": "textarea",
-                        "label": "Prompt",
-                        "description": "Prompt for feedback evaluation",
+                        "label": trans("agent.option.prompt"),
+                        "description": trans("agent.option.prompt.feedback.desc"),
                         "default": self.PROMPT_FEEDBACK,
                     },
                     "allow_local_tools": {
                         "type": "bool",
-                        "label": "Allow local tools",
-                        "description": "Allow usage of local tools for this agent",
+                        "label": trans("agent.option.tools.local"),
+                        "description": trans("agent.option.tools.local.desc"),
                         "default": False,
                     },
                     "allow_remote_tools": {
                         "type": "bool",
-                        "label": "Allow remote tools",
-                        "description": "Allow usage of remote tools for this agent",
+                        "label": trans("agent.option.tools.remote"),
+                        "description": trans("agent.option.tools.remote.desc"),
                         "default": False,
                     },
                 }
