@@ -6,12 +6,18 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.08 19:00:00                  #
+# Updated Date: 2025.09.01 23:00:00                  #
 # ================================================== #
 
 from packaging.version import parse as parse_version, Version
 
-from pygpt_net.core.types import MODE_RESEARCH, MODE_CHAT, MODE_AGENT_OPENAI, MODE_COMPUTER, MODE_EXPERT
+from pygpt_net.core.types import (
+    MODE_RESEARCH,
+    MODE_CHAT,
+    MODE_AGENT_OPENAI,
+    MODE_COMPUTER,
+    MODE_EXPERT
+)
 
 
 class Patch:
@@ -753,6 +759,45 @@ class Patch:
                     data["gpt-4.1-nano"] = base_data["gpt-4.1-nano"]
                 updated = True
 
+            # < 2.6.21 <-- add OpenAI Agents to Ollama
+            if old < parse_version("2.6.21"):
+                print("Migrating models from < 2.6.21...")
+                for id in data:
+                    model = data[id]
+                    if model.provider in ["ollama"]:
+                        if "agent_openai" not in model.mode:
+                            model.mode.append(MODE_AGENT_OPENAI)
+                updated = True
+
+            # <  2.6.30 <--- add Google Imagen models
+            if old < parse_version("2.6.30"):
+                print("Migrating models from < 2.6.30...")
+                if "imagen-3.0-generate-002" not in data:
+                    data["imagen-3.0-generate-002"] = base_data["imagen-3.0-generate-002"]
+                if "imagen-4.0-generate-001" not in data:
+                    data["imagen-4.0-generate-001"] = base_data["imagen-4.0-generate-001"]
+                updated = True
+
+            # <  2.6.31 <--- add realtime models
+            if old < parse_version("2.6.31"):
+                print("Migrating models from < 2.6.31...")
+                if "gemini-2.5-flash-preview-native-audio-dialog" not in data:
+                    data["gemini-2.5-flash-preview-native-audio-dialog"] = base_data["gemini-2.5-flash-preview-native-audio-dialog"]
+                if "gpt-realtime" not in data:
+                    data["gpt-realtime"] = base_data["gpt-realtime"]
+                if "gpt-4o-realtime-preview" not in data:
+                    data["gpt-4o-realtime-preview"] = base_data["gpt-4o-realtime-preview"]
+                updated = True
+
+            # add veo-3.0-generate-preview
+            if old < parse_version("2.6.32"):
+                print("Migrating models from < 2.6.32...")
+                if "veo-3.0-generate-preview" not in data:
+                    data["veo-3.0-generate-preview"] = base_data["veo-3.0-generate-preview"]
+                if "veo-3.0-fast-generate-preview" not in data:
+                    data["veo-3.0-fast-generate-preview"] = base_data["veo-3.0-fast-generate-preview"]
+                updated = True
+
         # update file
         if updated:
             data = dict(sorted(data.items()))
