@@ -6,10 +6,12 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.06 01:00:00                  #
+# Updated Date: 2025.08.28 09:00:00                  #
 # ================================================== #
-from typing import List, Dict
 
+from typing import List, Dict, Optional
+
+from llama_index.core.base.embeddings.base import BaseEmbedding
 from llama_index.core.llms.llm import BaseLLM as LlamaBaseLLM
 
 from pygpt_net.core.types import (
@@ -31,7 +33,7 @@ class AnthropicLLM(BaseLLM):
         """
         self.id = "anthropic"
         self.name = "Anthropic"
-        self.type = [MODE_LLAMA_INDEX]
+        self.type = [MODE_LLAMA_INDEX, "embeddings"]
 
     def llama(
             self,
@@ -51,8 +53,36 @@ class AnthropicLLM(BaseLLM):
         args = self.parse_args(model.llama_index, window)
         if "model" not in args:
             args["model"] = model.id
+        if "api_key" not in args or args["api_key"] == "":
+            args["api_key"] = window.core.config.get("api_key_anthropic", "")
         return Anthropic(**args)
 
+    def get_embeddings_model(
+            self,
+            window,
+            config: Optional[List[Dict]] = None
+    ) -> BaseEmbedding:
+        """
+        Return provider instance for embeddings
+
+        :param window: window instance
+        :param config: config keyword arguments list
+        :return: Embedding provider instance
+        """
+        from llama_index.embeddings.voyageai import VoyageEmbedding
+        args = {}
+        if config is not None:
+            args = self.parse_args({
+                "args": config,
+            }, window)
+        if "api_key" in args:
+            args["voyage_api_key"] = args.pop("api_key")
+        if "voyage_api_key" not in args or args["voyage_api_key"] == "":
+            args["voyage_api_key"] = window.core.config.get("api_key_voyage", "")
+        if "model" in args and "model_name" not in args:
+            args["model_name"] = args.pop("model")
+        return VoyageEmbedding(**args)
+
     def get_models(
             self,
             window,
@@ -63,11 +93,9 @@ class AnthropicLLM(BaseLLM):
         :param window: window instance
         :return: list of models
         """
-        items = []
-        from llama_index.llms.anthropic import Anthropic
-        api_key = window.core.config.get('api_key_anthropic', "")
-        client = Anthropic(api_key=api_key)
+        client = window.core.api.anthropic.get_client()
         models_list = client.models.list()
+        items = []
         if models_list.data:
             for item in models_list.data:
                 items.append({
