@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.06 01:00:00                  #
+# Updated Date: 2025.08.26 19:00:00                  #
 # ================================================== #
 
 import os
@@ -47,6 +47,8 @@ class MistralAILLM(BaseLLM):
         args = self.parse_args(model.llama_index, window)
         if "model" not in args:
             args["model"] = model.id
+        if "api_key" not in args or args["api_key"] == "":
+            args["api_key"] = window.core.config.get("api_key_mistral", "")
         return MistralAI(**args)
 
     def get_embeddings_model(
@@ -67,6 +69,10 @@ class MistralAILLM(BaseLLM):
             args = self.parse_args({
                 "args": config,
             }, window)
+        if "api_key" not in args or args["api_key"] == "":
+            args["api_key"] = window.core.config.get("api_key_mistral", "")
+        if "model" in args and "model_name" not in args:
+            args["model_name"] = args.pop("model")
         return MistralAIEmbedding(**args)
 
     def init_embeddings(
@@ -87,3 +93,25 @@ class MistralAILLM(BaseLLM):
         if ('OPENAI_API_KEY' not in os.environ
                 and (window.core.config.get('api_key') is None or window.core.config.get('api_key') == "")):
             os.environ['OPENAI_API_KEY'] = "_"
+
+    def get_models(
+            self,
+            window,
+    ) -> List[Dict]:
+        """
+        Return list of models for the provider
+
+        :param window: window instance
+        :return: list of models
+        """
+        items = []
+        client = self.get_client(window)
+        models_list = client.models.list()
+        if models_list.data:
+            for item in models_list.data:
+                id = item.id
+                items.append({
+                    "id": id,
+                    "name": id,
+                })
+        return items
