@@ -6,11 +6,12 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.15 03:00:00                  #
+# Updated Date: 2025.08.22 10:00:00                  #
 # ================================================== #
 
 from PySide6.QtCore import Qt
 from PySide6.QtWidgets import QHBoxLayout, QLabel, QVBoxLayout, QSizePolicy, QWidget, QFrame
+from PySide6.QtGui import QFont
 
 from pygpt_net.ui.widget.element.labels import TitleLabel, UrlLabel
 from pygpt_net.ui.widget.option.checkbox import OptionCheckbox
@@ -57,7 +58,9 @@ class BaseConfigDialog:
                 if slider and t in ('int', 'float'):
                     widgets[key] = OptionSlider(self.window, id, key, option)
                 else:
-                    widgets[key] = PasswordInput(self.window, id, key, option) if secret else OptionInput(self.window, id, key, option)
+                    widgets[key] = PasswordInput(self.window, id, key, option) if secret else OptionInput(self.window,
+                                                                                                          id, key,
+                                                                                                          option)
 
             elif t == 'textarea':
                 w = OptionTextarea(self.window, id, key, option)
@@ -88,6 +91,20 @@ class BaseConfigDialog:
 
         return widgets
 
+    def trans_or_not(self, label: str):
+        """
+        Translate label or return it as is if translation is not available
+
+        :param label: Label to translate
+        :return: Translated label or original if not found
+        """
+        txt = trans(label)
+        if txt == label:
+            if txt.startswith("dictionary."):
+                # get only last part after the dot
+                txt = txt.split('.')[-1].capitalize()
+        return txt
+
     def add_option(self, widget: QWidget, option: dict) -> QHBoxLayout:
         """
         Add option
@@ -99,20 +116,21 @@ class BaseConfigDialog:
         label = option['label']
         desc = option.get('description')
         extra = option.get('extra') or {}
-        label_key = label + '.label'
+        label_key = f'{label}.label'
         nodes = self.window.ui.nodes
 
+        txt = self.trans_or_not(label)
         if extra.get('bold'):
-            nodes[label_key] = TitleLabel(trans(label))
+            nodes[label_key] = TitleLabel(txt)
         else:
-            nodes[label_key] = QLabel(trans(label))
+            nodes[label_key] = QLabel(txt)
         nodes[label_key].setSizePolicy(QSizePolicy.Fixed, QSizePolicy.Preferred)
         nodes[label_key].setMinimumWidth(120)
         nodes[label_key].setWordWrap(True)
 
         desc_key = None
         if desc is not None:
-            desc_key = label + '.desc'
+            desc_key = f'{label}.desc'
             nodes[desc_key] = self.add_description(desc)
 
         if option.get('type') == 'textarea':
@@ -142,21 +160,22 @@ class BaseConfigDialog:
         :return: QHBoxLayout
         """
         label = option['label']
-        label_key = label + '.label'
+        label_key = f'{label}.label'
         desc = option.get('description')
         extra = option.get('extra') or {}
         nodes = self.window.ui.nodes
 
+        txt = self.trans_or_not(label)
         if extra.get('bold'):
-            nodes[label_key] = TitleLabel(trans(label))
+            nodes[label_key] = TitleLabel(txt)
         else:
-            nodes[label_key] = QLabel(trans(label))
+            nodes[label_key] = QLabel(txt)
         nodes[label_key].setMinimumHeight(30)
         nodes[label_key].setWordWrap(True)
 
         desc_key = None
         if desc is not None:
-            desc_key = label + '.desc'
+            desc_key = f'{label}.desc'
             nodes[desc_key] = self.add_description(desc)
 
         layout = QVBoxLayout()
@@ -191,7 +210,7 @@ class BaseConfigDialog:
 
         desc_key = None
         if desc is not None:
-            desc_key = label + '.desc'
+            desc_key = f'{label}.desc'
             nodes[desc_key] = self.add_description(desc)
 
         urls = extra.get('urls')
