@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.11.17 03:00:00                  #
+# Updated Date: 2025.08.24 23:00:00                  #
 # ================================================== #
 
 from PySide6 import QtCore
@@ -16,7 +16,6 @@ from PySide6.QtWidgets import QVBoxLayout, QHBoxLayout, QPushButton, QWidget
 from pygpt_net.ui.widget.element.labels import HelpLabel, TitleLabel
 from pygpt_net.ui.widget.lists.assistant import AssistantList
 from pygpt_net.utils import trans
-import pygpt_net.icons_rc
 
 class Assistants:
     def __init__(self, window=None):
@@ -48,49 +47,50 @@ class Assistants:
 
         :return: QVBoxLayout
         """
+        nodes = self.window.ui.nodes
+        ctrl = self.window.controller
+
         # new
-        self.window.ui.nodes['assistants.new'] = QPushButton(QIcon(":/icons/add.svg"), "")
-        self.window.ui.nodes['assistants.new'].clicked.connect(
-            lambda: self.window.controller.assistant.editor.edit())
+        nodes['assistants.new'] = QPushButton(QIcon(":/icons/add.svg"), "")
+        _cb_new = ctrl.assistant.editor.edit
+        nodes['assistants.new'].clicked.connect(lambda checked=False, cb=_cb_new: cb())
 
         # import
-        self.window.ui.nodes['assistants.import'] = QPushButton(trans('assistant.import'))
-        self.window.ui.nodes['assistants.import'].clicked.connect(
-            lambda: self.window.controller.assistant.batch.import_assistants()
-        )
+        nodes['assistants.import'] = QPushButton(trans('assistant.import'))
+        _cb_import = ctrl.assistant.batch.import_assistants
+        nodes['assistants.import'].clicked.connect(lambda checked=False, cb=_cb_import: cb())
 
         # label
-        self.window.ui.nodes['assistants.label'] = TitleLabel(trans("toolbox.assistants.label"))
+        nodes['assistants.label'] = TitleLabel(trans("toolbox.assistants.label"))
 
         # header
         header = QHBoxLayout()
-        header.addWidget(self.window.ui.nodes['assistants.label'])
+        header.addWidget(nodes['assistants.label'])
         header.addStretch(1)
-
-        header.addWidget(self.window.ui.nodes['assistants.new'], alignment=Qt.AlignRight)
-        header.addWidget(self.window.ui.nodes['assistants.import'], alignment=Qt.AlignRight)
+        header.addWidget(nodes['assistants.new'], alignment=Qt.AlignRight)
+        header.addWidget(nodes['assistants.import'], alignment=Qt.AlignRight)
         header.setContentsMargins(5, 0, 0, 0)
         header_widget = QWidget()
         header_widget.setLayout(header)
 
         # list
-        self.window.ui.nodes[self.id] = AssistantList(self.window, self.id)
-        self.window.ui.nodes[self.id].selection_locked = self.window.controller.assistant.change_locked
-        self.window.ui.nodes[self.id].setMinimumWidth(40)
+        nodes[self.id] = AssistantList(self.window, self.id)
+        nodes[self.id].selection_locked = ctrl.assistant.change_locked
+        nodes[self.id].setMinimumWidth(40)
 
-        self.window.ui.nodes['tip.toolbox.assistants'] = HelpLabel(trans('tip.toolbox.assistants'), self.window)
-        self.window.ui.nodes['tip.toolbox.assistants'].setAlignment(Qt.AlignCenter)
+        nodes['tip.toolbox.assistants'] = HelpLabel(trans('tip.toolbox.assistants'), self.window)
+        nodes['tip.toolbox.assistants'].setAlignment(Qt.AlignCenter)
 
         # rows
         layout = QVBoxLayout()
         layout.addWidget(header_widget)
-        layout.addWidget(self.window.ui.nodes[self.id])
-        layout.addWidget(self.window.ui.nodes['tip.toolbox.assistants'])
+        layout.addWidget(nodes[self.id])
+        layout.addWidget(nodes['tip.toolbox.assistants'])
         layout.setContentsMargins(2, 5, 5, 5)
 
         # model
-        self.window.ui.models[self.id] = self.create_model(self.window)
-        self.window.ui.nodes[self.id].setModel(self.window.ui.models[self.id])
+        self.window.ui.models[self.id] = self.create_model(nodes[self.id])
+        nodes[self.id].setModel(self.window.ui.models[self.id])
 
         return layout
 
@@ -109,18 +109,22 @@ class Assistants:
 
         :param data: Data to update
         """
-        # store previous selection
-        self.window.ui.nodes[self.id].backup_selection()
+        view = self.window.ui.nodes[self.id]
+        model = self.window.ui.models[self.id]
 
-        self.window.ui.models[self.id].removeRows(0, self.window.ui.models[self.id].rowCount())
-        i = 0
-        for n in data:
-            self.window.ui.models[self.id].insertRow(i)
-            name = data[n].name
-            index = self.window.ui.models[self.id].index(i, 0)
-            self.window.ui.models[self.id].setData(index, "ID: " + data[n].id, QtCore.Qt.ToolTipRole)
-            self.window.ui.models[self.id].setData(self.window.ui.models[self.id].index(i, 0), name)
-            i += 1
+        view.backup_selection()
+        view.setUpdatesEnabled(False)
+        try:
+            with QtCore.QSignalBlocker(model):
+                model.setRowCount(0)
+                count = len(data)
+                if count:
+                    model.setRowCount(count)
+                    for i, item in enumerate(data.values()):
+                        index = model.index(i, 0)
+                        model.setData(index, "ID: " + item.id, QtCore.Qt.ToolTipRole)
+                        model.setData(index, item.name)
+        finally:
+            view.setUpdatesEnabled(True)
 
-        # restore previous selection
-        self.window.ui.nodes[self.id].restore_selection()
+        view.restore_selection()
\ No newline at end of file
